Learn R Programming

PHENTHAUproc (version 1.1.1)

calc_baskerville: Calculate degree days using the single sine method of Baskerville

Description

The function is vectorized. To use it with SpatRaster data see ?terra::lapp

More Information about the Method itself: Baskerville, G.L. and P. Emin. 1969. Rapid estimation of heat accumulation from maximum and minimum temperature. Ecology 50:514-517.

Usage

calc_baskerville(tmin, tmax, ldt)

Value

Degree days calculated by using the single sine method of Baskerville.

Arguments

tmin

min temperature - numeric

tmax

max temperature - numeric

ldt

lower development threshold aka base temperature - numeric

See Also

Other Temperature sum methods: calc_tsum()