Learn R Programming

PHENTHAUproc (version 1.1.1)

calc_phenology: Calculate phenological models

Description

This function is checking the dependencies of the model and dependent on them:

1 Calculate the needed sum of effective (SET) temperatures for the phenological event to happen 2 Calculate the summed degree days (depending on hatch or not) 3 Check if the summed degree days have reached the needed sum of effective temperatures

Usage

calc_phenology(x, params)

Value

SpatRaster - logical - with event occurred/not TRUE/FALSE

Arguments

x

SpatRaster list - with tmean, tmin, tmax and time attribute

params

parameter list

See Also

Other Models: calc_degreedays(), calc_mortality(), calc_sumefftemp()