Internal function to create a SpatRaster list out of a dataframe.
By default the dataframe should have a date column called "date". The function is transferring each column into a list object and this object to a 1 col, 1 row nrow nlyr SpatRaster.
convert_df_to_srl(x, date_col = "date")SpatRaster list (tmean, tmax, tmin) - numeric - with time attribute
dataframe (tmean, tmax, tmin, date)
character - name for date column which will be used to create time attribute of SpatRaster.
Other SpatRaster transformation:
convert_doy_to_logical(),
convert_hour_to_meanminmax(),
convert_logical_to_doy(),
convert_logical_to_time(),
convert_sr_to_cvec()