This function is checking the dependencies of the model and dependent on them:
1 Calculate the needed sum of effective (SET) temperatures for the phenological event to happen 2 Calculate the summed degree days (depending on hatch or not) 3 Check if the summed degree days have reached the needed sum of effective temperatures
calc_phenology(x, params)SpatRaster - logical - with event occurred/not TRUE/FALSE
SpatRaster list - with tmean, tmin, tmax and time attribute
parameter list
Other Models:
calc_degreedays(),
calc_mortality(),
calc_sumefftemp()